# 👾 bluer-agent

👾 `@agent` is a set of tools for interacting with LLMs.

## installation

```bash
pip install bluer-agent
```

## features

|   |   |
| --- | --- |
| [`chat`](./bluer_agent/docs/chat) [![image](https://github.com/kamangir/assets2/raw/main/bluer-agent/icon.jpg?raw=true)](./bluer_agent/docs/chat)  | [`transcription`](./bluer_agent/docs/transcription) [![image](https://github.com/kamangir/assets2/raw/main/bluer-agent/icon.jpg?raw=true)](./bluer_agent/docs/transcription)  |

# aliases

[@agent](./bluer_agent/docs/aliases/agent.md), 
[@audio](./bluer_agent/docs/aliases/audio.md).

---


[![pylint](https://github.com/kamangir/bluer-agent/actions/workflows/pylint.yml/badge.svg)](https://github.com/kamangir/bluer-agent/actions/workflows/pylint.yml) [![pytest](https://github.com/kamangir/bluer-agent/actions/workflows/pytest.yml/badge.svg)](https://github.com/kamangir/bluer-agent/actions/workflows/pytest.yml) [![bashtest](https://github.com/kamangir/bluer-agent/actions/workflows/bashtest.yml/badge.svg)](https://github.com/kamangir/bluer-agent/actions/workflows/bashtest.yml) [![PyPI version](https://img.shields.io/pypi/v/bluer-agent.svg)](https://pypi.org/project/bluer-agent/) [![PyPI - Downloads](https://img.shields.io/pypi/dd/bluer-agent)](https://pypistats.org/packages/bluer-agent)

built by 🌀 [`bluer README`](https://github.com/kamangir/bluer-objects/tree/main/bluer_objects/README), based on 👾 [`bluer_agent-5.52.1`](https://github.com/kamangir/bluer-agent).
